<?php
namespace WSCOMUN\CATASTRO;

use WSCOMUN\WSComunFClient;
use ArrayObject;
use DateTime;
use Exception;
use SoapVar;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Catastro
 *
 * @package		WSClientCatastro
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientCatastro extends WSComunFClient
{

	/**
	 *
	 * @param mixed $IdPeticion
	 * @param mixed $NumElementos
	 * @param mixed $TimeStamp
	 * @param mixed $CodigoCertificado
	 * @param mixed $NifEmisor
	 * @param mixed $NombreEmisor
	 * @param mixed $CodProcedimiento
	 * @param mixed $NombreProcedimiento
	 * @param mixed $NombreCompletoFuncionario
	 * @param mixed $NifFuncionario
	 * @param mixed $IdentificadorSolicitante
	 * @param mixed $NombreSolicitante
	 * @param mixed $UnidadTramitadora
	 * @param mixed $Finalidad
	 * @param mixed $Consentimiento
	 * @param mixed $IdExpediente
	 * @param mixed $TipoDocumentacion
	 * @param mixed $Documentacion
	 * @param mixed $NombreCompleto
	 * @param mixed $Nombre
	 * @param mixed $Apellido1
	 * @param mixed $Apellido2
	 * @param mixed $CodigoCertificado
	 * @param mixed $IdSolicitud
	 * @param mixed $vDataEspecifico
	 * @return array
	 */
	public function catastro($IdPeticion, $NumElementos, $TimeStamp, $CodigoCertificado,
			$NifEmisor, $NombreEmisor, $CodProcedimiento, $NombreProcedimiento,
			$NombreCompletoFuncionario, $NifFuncionario, $IdentificadorSolicitante, $NombreSolicitante,
			$UnidadTramitadora, $Finalidad, $Consentimiento,
			$IdExpediente, $TipoDocumentacion, $Documentacion, $NombreCompleto,
			$Nombre, $Apellido1, $Apellido2, $CodigoCertificado, $IdSolicitud, $vDataEspecifico)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO);


			// TODO: Sincrona
			$IdSolicitud = $IdPeticion;

			// $CodigoCertificado debera ser auto-generado
			// IdentificadorSolicitante = (Sugerido) CODxxxxxx
			// Consentimiento = Si | Ley
			// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

			//$compEspecifico = new ComposerCatastro();//

			// Atributos
			$AtributosWSRequest = new ArrayObject();
			$AtributosWSRequest->append(new SoapVar($IdPeticion, XSD_STRING, null, null,'IdPeticion', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($NumElementos, XSD_INTEGER , null, null,'NumElementos', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($TimeStamp->format(DateTime::ATOM), XSD_STRING, null, null,'TimeStamp', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_CAT_PET));

			// Emisor
			$EmisorWSRequest = new ArrayObject();
			$EmisorWSRequest->append(new SoapVar($NifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_CAT_PET));
			$EmisorWSRequest->append(new SoapVar($NombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_CAT_PET));

			// Procedimiento
			$ProcedimientoWSRequest = new ArrayObject();
			$ProcedimientoWSRequest->append(new SoapVar($CodProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_CAT_PET));
			$ProcedimientoWSRequest->append(new SoapVar($NombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_CAT_PET));

			// Funcionario
			$FuncionarioWSRequest = new ArrayObject();
			$FuncionarioWSRequest->append(new SoapVar($NombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_CAT_PET));
			$FuncionarioWSRequest->append(new SoapVar($NifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_CAT_PET));

			// Solicitante
			$SolicitanteWSRequest = new ArrayObject();
			$SolicitanteWSRequest->append(new SoapVar($IdentificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_CAT_PET));
			$SolicitanteWSRequest->append(new SoapVar($NombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_CAT_PET));
			$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_CAT_PET));
			$SolicitanteWSRequest->append(new SoapVar($Finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_CAT_PET));
			$SolicitanteWSRequest->append(new SoapVar($Consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_CAT_PET));
			$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_CAT_PET));

			// Titular
			$TitularWSRequest = new ArrayObject();
			$TitularWSRequest->append(new SoapVar($TipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_CAT_PET));
			$TitularWSRequest->append(new SoapVar($Documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_CAT_PET));


			// Transmision
			$TransmisionWSRequest = new ArrayObject();
			$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_CAT_PET));
			$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_CAT_PET));

			// DatosGenericos
			$DatosGenericosWSRequest = new ArrayObject();
			$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_CAT_PET));
			$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_CAT_PET));
			$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_CAT_PET));
			$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_CAT_PET));

			// SolicitudTransmision
			$SolicitudTransmisionWSRequest = new ArrayObject();
			$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_CAT_PET));


			// Solicitudes
			$SolicitudesWSRequest = new ArrayObject();
			$SolicitudesWSRequest->append(new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_CAT_PET));

			// Body
			$bodyWSRequest = new ArrayObject();
			$bodyWSRequest->append(new SoapVar($AtributosWSRequest, SOAP_ENC_OBJECT,null,null,'Atributos', self::$NAMESPACE_CAT_PET));
			$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitudes', self::$NAMESPACE_CAT_PET));

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'Peticion', self::$NAMESPACE_CAT_PET);

			$respuesta = $clienteWS->peticionSincrona($miSoapRQ);

			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastro


	/**
	 *
	 * @param mixed $IdPeticion
	 * @param mixed $TimeStamp
	 * @param mixed $CodigoCertificado
	 * @param mixed $NifEmisor
	 * @param mixed $NombreEmisor
	 * @param mixed $CodProcedimiento
	 * @param mixed $NombreProcedimiento
	 * @param mixed $NombreCompletoFuncionario
	 * @param mixed $NifFuncionario
	 * @param mixed $IdentificadorSolicitante
	 * @param mixed $NombreSolicitante
	 * @param mixed $UnidadTramitadora
	 * @param mixed $Finalidad
	 * @param mixed $Consentimiento
	 * @param mixed $IdExpediente
	 * @param mixed $TipoDocumentacion
	 * @param mixed $Documentacion
	 * @param mixed $NombreCompleto
	 * @param mixed $Nombre
	 * @param mixed $Apellido1
	 * @param mixed $Apellido2
	 * @param mixed $CodigoCertificado
	 * @param mixed $IdSolicitud
	 * @param mixed $vDataEspecifico
	 * @return array
	 */
	public function catastroBienesPeticion($IdPeticion, $TimeStamp, $CodigoCertificado,
			$NifEmisor, $NombreEmisor, $CodProcedimiento, $NombreProcedimiento,
			$NombreCompletoFuncionario, $NifFuncionario, $IdentificadorSolicitante, $NombreSolicitante,
			$UnidadTramitadora, $Finalidad, $Consentimiento,
			$IdExpediente, $TipoDocumentacion, $Documentacion, $NombreCompleto,
			$Nombre, $Apellido1, $Apellido2, $CodigoCertificado, $IdSolicitud, $vDataEspecifico)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO_BIENES, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO_BIENES);

			/*
			 $this->__clienteOn(self::KEYCLIENTE_CATASTRO, true);
			 $clienteWS = $this->v_clienteWS[self::KEYCLIENTE_CATASTRO];
			 */

			// Cuenta el numero de elemento
			$NumElementos = count($vDataEspecifico);

			// Atributos
			$AtributosWSRequest = new ArrayObject();
			$AtributosWSRequest->append(new SoapVar($IdPeticion, XSD_STRING, null, null,'IdPeticion', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($NumElementos, XSD_INTEGER , null, null,'NumElementos', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($TimeStamp->format(DateTime::ATOM), XSD_STRING, null, null,'TimeStamp', self::$NAMESPACE_CAT_PET));
			$AtributosWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_CAT_PET));

			// Solicitudes
			$SolicitudesWSRequest = new ArrayObject();


			for ($iPet=0; $iPet < $NumElementos; $iPet++) {
				// TODO: Sincrona
				$IdSolicitud = $IdPeticion . '_' . $iPet;

				// $CodigoCertificado debera ser auto-generado
				// IdentificadorSolicitante = (Sugerido) CODxxxxxx
				// Consentimiento = Si | Ley
				// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

				$compEspecifico = new ComposerCatastro();
				$vDataPeticion = array( 'DatosEntrada' => $vDataEspecifico[$iPet]);
				$DatosEspecificosWSRequest = $compEspecifico->doIt($vDataPeticion);	// $NAMESPACE_CAT_ESP


				// Emisor
				$EmisorWSRequest = new ArrayObject();
				$EmisorWSRequest->append(new SoapVar($NifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_CAT_PET));
				$EmisorWSRequest->append(new SoapVar($NombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_CAT_PET));

				// Procedimiento
				$ProcedimientoWSRequest = new ArrayObject();
				$ProcedimientoWSRequest->append(new SoapVar($CodProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_CAT_PET));
				$ProcedimientoWSRequest->append(new SoapVar($NombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_CAT_PET));

				// Funcionario
				$FuncionarioWSRequest = new ArrayObject();
				$FuncionarioWSRequest->append(new SoapVar($NombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_CAT_PET));
				$FuncionarioWSRequest->append(new SoapVar($NifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_CAT_PET));

				// Solicitante
				$SolicitanteWSRequest = new ArrayObject();
				$SolicitanteWSRequest->append(new SoapVar($IdentificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_CAT_PET));
				$SolicitanteWSRequest->append(new SoapVar($NombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_CAT_PET));
				//$SolicitanteWSRequest->append(new SoapVar($UnidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_CAT_PET));
				$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_CAT_PET));
				$SolicitanteWSRequest->append(new SoapVar($Finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_CAT_PET));
				$SolicitanteWSRequest->append(new SoapVar($Consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_CAT_PET));
				$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_CAT_PET));
				//$SolicitanteWSRequest->append(new SoapVar($IdExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_CAT_PET));

				// Titular
				$TitularWSRequest = new ArrayObject();
				$TitularWSRequest->append(new SoapVar($TipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_CAT_PET));
				$TitularWSRequest->append(new SoapVar($Documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_CAT_PET));
				//$TitularWSRequest->append(new SoapVar($NombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_CAT_PET));
				//$TitularWSRequest->append(new SoapVar($Nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_CAT_PET));
				//$TitularWSRequest->append(new SoapVar($Apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_CAT_PET));
				//$TitularWSRequest->append(new SoapVar($Apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_CAT_PET));

				// Transmision
				$TransmisionWSRequest = new ArrayObject();
				$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_CAT_PET));
				$TransmisionWSRequest->append(new SoapVar($IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_CAT_PET));

				// DatosGenericos
				$DatosGenericosWSRequest = new ArrayObject();
				$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_CAT_PET));
				$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_CAT_PET));
				$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_CAT_PET));
				$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_CAT_PET));

				// SolicitudTransmision
				$SolicitudTransmisionWSRequest = new ArrayObject();
				$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_CAT_PET));
				$SolicitudTransmisionWSRequest->append(new SoapVar($DatosEspecificosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosEspecificos', self::$NAMESPACE_CAT_ESP));


				// Aade la solicitud de transmision al listado de solicitudes
				$SolicitudesWSRequest->append(new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_CAT_PET));
			}

			// Body
			$bodyWSRequest = new ArrayObject();
			$bodyWSRequest->append(new SoapVar($AtributosWSRequest, SOAP_ENC_OBJECT,null,null,'Atributos', self::$NAMESPACE_CAT_PET));
			$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitudes', self::$NAMESPACE_CAT_PET));


			//			var_dump($clienteWS);die;

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'Peticion', self::$NAMESPACE_CAT_PET);


			$respuesta = $clienteWS->peticionAsincrona($miSoapRQ);

			//			var_dump($respuesta);die;
			//var_dump($respuesta->respuesta);die;


			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastroBienesPeticion

	public function catastroBienesRespuesta($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO_BIENES, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO_BIENES);

			/*
			 $this->__clienteOn(self::KEYCLIENTE_CATASTRO, true);
			 $clienteWS = $this->v_clienteWS[self::KEYCLIENTE_CATASTRO];
			 */


			// Atributos
			$AtributosWSRequest = new ArrayObject();
			$AtributosWSRequest->append(new SoapVar($IdPeticion, XSD_STRING, null, null,'IdPeticion', self::$NAMESPACE_CAT_SR));
			$AtributosWSRequest->append(new SoapVar($NumElementos, XSD_INTEGER , null, null,'NumElementos', self::$NAMESPACE_CAT_SR));
			$AtributosWSRequest->append(new SoapVar($TimeStamp->format(DateTime::ATOM), XSD_STRING, null, null,'TimeStamp', self::$NAMESPACE_CAT_SR));
			$AtributosWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_CAT_SR));

			// Body
			$bodyWSRequest = new ArrayObject();
			$bodyWSRequest->append(new SoapVar($AtributosWSRequest, SOAP_ENC_OBJECT,null,null,'Atributos', self::$NAMESPACE_CAT_SR));

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudRespuesta', self::$NAMESPACE_CAT_SR);
			$respuesta = $clienteWS->solicitudRespuesta($miSoapRQ);

			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastroBienesRespuesta


	public function catastroB($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO);

			// $CodigoCertificado debera ser auto-generado
			// IdentificadorSolicitante = (Sugerido) CODxxxxxx
			// Consentimiento = Si | Ley
			// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

			$oCatastro = new objCatastro();
			$bodyWSRequest = $oCatastro->doGeneral($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'Peticion', self::$NAMESPACE_CAT_PET);
			$respuesta = $clienteWS->peticionSincrona($miSoapRQ);

			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastro

	public function catastroBienesPeticionB($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO_BIENES, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO_BIENES);


			$oCatastro = new objCatastro();
			$bodyWSRequest = $oCatastro->catastroBienesPeticion($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null, 'Peticion', self::$NAMESPACE_CAT_PET);
			$respuesta = $clienteWS->peticionAsincrona($miSoapRQ);


			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastroBienesPeticion

	public function catastroBienesRespuestaB($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		try
		{

			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_CATASTRO_BIENES, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CATASTRO_BIENES);

			$oCatastro = new objCatastro();
			$bodyWSRequest = $oCatastro->catastroBienesRespuesta($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudRespuesta', self::$NAMESPACE_CAT_SR);
			$respuesta = $clienteWS->solicitudRespuesta($miSoapRQ);

			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
					'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//catastroBienesRespuestaB


}

?>