<?php

namespace WSCOMUN\DGP\CONSULTAIDENTIDAD;
use Exception;
use SoapVar;
use ArrayObject;
use stdClass;


const unbounded = 'unbounded';

/**
 * @param array $options Opciones del cliente SOAP
 * @param string $wsdl Ubicacin del WSDL
 * @access public
 */
class objSolicitudTransmision
{


	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP  = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR   = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';
	private static $NAMESPACE_RESP = 'http://intermediacion.redsara.es/scsp/esquemas/V3/respuesta';

	/**
	 * @var String $IdPeticion
	 */
	protected $IdPeticion = null;

	/**
	 * @var Int $NumElementos
	 */
	protected $NumElementos = null;

	/**
	 * @var String $TimeStamp
	 */
	protected $TimeStamp = null;

	/**
	 * @var Estado $Estado
	 */
	protected $Estado = null;

	/**
	 * @var string $CodigoCertificado
	 */
	protected $CodigoCertificado = null;

	/**
	 * @var string $IdSolicitud
	 */
	protected $IdSolicitud = null;


	/**
	 * @var DatosEspecificos
	 * Datos especficos de la peticion
	 */
	private $oEspecifico = null;

	/**
	 * @return string
	 */
	public function getIdPeticion()
	{
		return $this->IdPeticion;
	}

	/**
	 * @param string $IdPeticion
	 */
	public function setIdPeticion($IdPeticion)
	{
		$this->IdPeticion = $IdPeticion;
		return $this;
	}

	public function setIdSolicitud($IdSolicitud){
		$this->IdSolicitud = $IdSolicitud;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getNumElementos()
	{
		return $this->NumElementos;
	}

	/**
	 * @param int $NumElementos
	 */
	public function setNumElementos($NumElementos)
	{
		$this->NumElementos = $NumElementos;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getTimeStamp()
	{
		return $this->TimeStamp;
	}

	/**
	 * @param string $TimeStamp
	 */
	public function setTimeStamp($TimeStamp)
	{
		$this->TimeStamp = $TimeStamp;
		return $this;
	}

	/**
	 * @return Estado
	 */
	public function getEstado()
	{
		return $this->Estado;
	}

	/**
	 * @param Estado $Estado
	 */
	public function setEstado($Estado)
	{
		$this->Estado = $Estado;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getCodigoCertificado()
	{
		return $this->CodigoCertificado;
	}


	/**
	 * @var string $TipoDocumentacion
	 */
	protected $TipoDocumentacion = null;

	/**
	 * @var string $Documentacion
	 */
	protected $Documentacion = null;

	/**
	 * @var string $NombreCompleto
	 */
	protected $NombreCompleto = null;

	/**
	 * @var string $Nombre
	 */
	protected $Nombre = null;

	/**
	 * @var string $Apellido1
	 */
	protected $Apellido1 = null;

	/**
	 * @var string $Apellido2
	 */
	protected $Apellido2 = null;


	/**
	 * @var string $NifEmisor
	 */
	protected $NifEmisor = null;

	/**
	 * @var string $NombreEmisor
	 */
	protected $NombreEmisor = null;

	/**
	 * @param NifEmisor $NifEmisor
	 * @param NombreEmisor $NombreEmisor
	 */
	/**
	 * @var string $CodProcedimiento
	 */
	protected $CodProcedimiento = null;

	/**
	 * @var string $NombreProcedimiento
	 */
	protected $NombreProcedimiento = null;

	/**
	 * @var string $NombreCompletoFuncionario
	 */
	protected $NombreCompletoFuncionario = null;

	/**
	 * @var string $NifFuncionario
	 */
	protected $NifFuncionario = null;


	/**
	 * Establece los datos del ciudadano sobre el que se va a realizar la consulta.
	 * @param string $TipoDocumentacion
	 * @param string $Documentacion
	 * @param string $NombreCompleto
	 * @param string $Nombre
	 * @param string $Apellido1
	 * @param string $Apellido2
	 */
	public function setTitular($TipoDocumentacion, $Documentacion, $NombreCompleto, $Nombre, $Apellido1, $Apellido2)
	{
		$this->TipoDocumentacion = $TipoDocumentacion;
		$this->Documentacion = $Documentacion;
		$this->NombreCompleto = $NombreCompleto;
		$this->Nombre = $Nombre;
		$this->Apellido1 = $Apellido1;
		$this->Apellido2 = $Apellido2;
	}

	/**
	 * @param string $NifEmisor
	 * @param string $NombreEmisor
	 */

	public function setEmisor($NifEmisor, $NombreEmisor)
	{
		$this->NifEmisor = $NifEmisor;
		$this->NombreEmisor = $NombreEmisor;
		return $this;
	}

	/**
	 * @param string $CodProcedimiento
	 * @param string $NombreProcedimiento
	 */
	public function setProcedimiento($CodProcedimiento, $NombreProcedimiento)
	{
		$this->CodProcedimiento = $CodProcedimiento;
		$this->NombreProcedimiento = $NombreProcedimiento;
	}
	/**
	 * @param string $NombreCompletoFuncionario
	 * @param string $NifFuncionario
	 */

	public function setFuncionario($NombreCompletoFuncionario, $NifFuncionario)
	{
		$this->NombreCompletoFuncionario = $NombreCompletoFuncionario;
		$this->NifFuncionario = $NifFuncionario;
	}

	/**
	 * @param string $IdentificadorSolicitante
	 * @param string $NombreSolicitante
	 * @param string $UnidadTramitadora
	 * @param Procedimiento $Procedimiento
	 * @param string $Finalidad
	 * @param string $Consentimiento
	 * @param Funcionario $Funcionario
	 * @param string $IdExpediente
	 */

	/**
	 * @var string $IdentificadorSolicitante
	 */
	protected $IdentificadorSolicitante = null;

	/**
	 * @var string $NombreSolicitante
	 */
	protected $NombreSolicitante = null;

	/**
	 * @var string $UnidadTramitadora
	 */
	protected $UnidadTramitadora = null;

	/**
	 * @var string $Finalidad
	 */
	protected $Finalidad = null;

	/**
	 * @var string $Consentimiento
	 */
	protected $Consentimiento = null;

	/**
	 * @var string $IdExpediente
	 */
	protected $IdExpediente = null;

	public function setSolicitante($IdentificadorSolicitante, $NombreSolicitante, $UnidadTramitadora, $Finalidad, $Consentimiento, $IdExpediente)
	{
		$this->IdentificadorSolicitante = $IdentificadorSolicitante;
		$this->NombreSolicitante = $NombreSolicitante;
		$this->UnidadTramitadora = $UnidadTramitadora;
		$this->Finalidad = $Finalidad;
		$this->Consentimiento = $Consentimiento;
		$this->IdExpediente = $IdExpediente;
	}


	/**
	 * @param string $CodigoCertificado
	 */
	public function setCodigoCertificado($CodigoCertificado)
	{
		$this->CodigoCertificado = $CodigoCertificado;
		return $this;
	}

	/**
	 * Establece los datos especificos de la peticin.
	 *
	 * @access	public
	 * @param DatosEspecificos $oEspecifico Datos especficos de la consulta
	 */
	public function setEspecifico($oEspecifico) {
		$this->oEspecifico = $oEspecifico;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @access 	public
	 * @param string $IdPeticion Identificador de la peticin
	 * @param string $CodigoCertificado Cdigo del certificado del servicio que solicita la peticion
	 * @param string $numParcial Subidentificador de la peticin. Cuando se suministra, se concatena al identificador de la peticion.
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 */
	public function toSoap($IdPeticion, $CodigoCertificado, $numParcial = null)
	{
		//$IdSolicitud = $IdPeticion;
		if (!is_null($numParcial)) {
			$IdSolicitud = $IdPeticion . '_' . $numParcial;
		}

		// $CodigoCertificado debera ser auto-generado
		// IdentificadorSolicitante = (Sugerido) CODxxxxxx
		// Consentimiento = Si | Ley
		// TipoDocumentacion = NIF | CIF | DNI | Pasaporte | NIE

		// Emisor
		$EmisorWSRequest = new ArrayObject();
		$EmisorWSRequest->append(new SoapVar($this->NifEmisor, XSD_STRING, null, null,'NifEmisor', self::$NAMESPACE_PET));
		$EmisorWSRequest->append(new SoapVar($this->NombreEmisor, XSD_STRING, null, null,'NombreEmisor', self::$NAMESPACE_PET));

		// Procedimiento
		$ProcedimientoWSRequest = new ArrayObject();
		$ProcedimientoWSRequest->append(new SoapVar($this->CodProcedimiento, XSD_STRING, null, null,'CodProcedimiento', self::$NAMESPACE_PET));
		$ProcedimientoWSRequest->append(new SoapVar($this->NombreProcedimiento, XSD_STRING, null, null,'NombreProcedimiento', self::$NAMESPACE_PET));

		// Funcionario
		$FuncionarioWSRequest = new ArrayObject();
		$FuncionarioWSRequest->append(new SoapVar($this->NombreCompletoFuncionario, XSD_STRING, null, null,'NombreCompletoFuncionario', self::$NAMESPACE_PET));
		$FuncionarioWSRequest->append(new SoapVar($this->NifFuncionario, XSD_STRING, null, null,'NifFuncionario', self::$NAMESPACE_PET));

		// Solicitante
		$SolicitanteWSRequest = new ArrayObject();
		$SolicitanteWSRequest->append(new SoapVar($this->IdentificadorSolicitante, XSD_STRING, null, null,'IdentificadorSolicitante', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->NombreSolicitante, XSD_STRING, null, null,'NombreSolicitante', self::$NAMESPACE_PET));
		if (!is_null($this->UnidadTramitadora)) {
			$SolicitanteWSRequest->append(new SoapVar($this->UnidadTramitadora, XSD_STRING, null, null,'UnidadTramitadora', self::$NAMESPACE_PET));
		}
		$SolicitanteWSRequest->append(new SoapVar($ProcedimientoWSRequest, SOAP_ENC_OBJECT,null,null,'Procedimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->Finalidad, XSD_STRING, null, null,'Finalidad', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($this->Consentimiento, XSD_STRING, null, null,'Consentimiento', self::$NAMESPACE_PET));
		$SolicitanteWSRequest->append(new SoapVar($FuncionarioWSRequest, SOAP_ENC_OBJECT,null,null,'Funcionario', self::$NAMESPACE_PET));
		if (!is_null($this->IdExpediente)) {
			$SolicitanteWSRequest->append(new SoapVar($this->IdExpediente, XSD_STRING, null, null,'IdExpediente', self::$NAMESPACE_PET));
		}

		// Titular
		$TitularWSRequest = new ArrayObject();
		$TitularWSRequest->append(new SoapVar($this->TipoDocumentacion, XSD_STRING, null, null,'TipoDocumentacion', self::$NAMESPACE_PET));
		$TitularWSRequest->append(new SoapVar($this->Documentacion, XSD_STRING, null, null,'Documentacion', self::$NAMESPACE_PET));
		if (!is_null($this->NombreCompleto)) {
			$TitularWSRequest->append(new SoapVar($this->NombreCompleto, XSD_STRING, null, null,'NombreCompleto', self::$NAMESPACE_PET));
		}
		if (!is_null($this->Nombre)) {
			$TitularWSRequest->append(new SoapVar($this->Nombre, XSD_STRING, null, null,'Nombre', self::$NAMESPACE_PET));
		}
		if (!is_null($this->Apellido1)) {
			$TitularWSRequest->append(new SoapVar($this->Apellido1, XSD_STRING, null, null,'Apellido1', self::$NAMESPACE_PET));
		}
		if (!is_null($this->Apellido2)) {
			$TitularWSRequest->append(new SoapVar($this->Apellido2, XSD_STRING, null, null,'Apellido2', self::$NAMESPACE_PET));
		}

		// Transmision
		$TransmisionWSRequest = new ArrayObject();
		$TransmisionWSRequest->append(new SoapVar($CodigoCertificado, XSD_STRING, null, null,'CodigoCertificado', self::$NAMESPACE_PET));
		$TransmisionWSRequest->append(new SoapVar($this->IdSolicitud, XSD_STRING, null, null,'IdSolicitud', self::$NAMESPACE_PET));

		// DatosGenericos
		$DatosGenericosWSRequest = new ArrayObject();
		$DatosGenericosWSRequest->append(new SoapVar($EmisorWSRequest, SOAP_ENC_OBJECT,null,null,'Emisor', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($SolicitanteWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitante', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TitularWSRequest, SOAP_ENC_OBJECT,null,null,'Titular', self::$NAMESPACE_PET));
		$DatosGenericosWSRequest->append(new SoapVar($TransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'Transmision', self::$NAMESPACE_PET));

		// SolicitudTransmision
		$SolicitudTransmisionWSRequest = new ArrayObject();
		$SolicitudTransmisionWSRequest->append(new SoapVar($DatosGenericosWSRequest, SOAP_ENC_OBJECT,null,null,'DatosGenericos', self::$NAMESPACE_PET));

		// Devuelve la solicitud ya generada
		return new SoapVar($SolicitudTransmisionWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudTransmision', self::$NAMESPACE_PET);
	}

}


class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
		//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
			//var_dump($childData);
			//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
			//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

		//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
				//				var_dump($vChildData);die;
			}
		}

		//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
					//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
					//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
					//					return true;
				}
			} else {
				return false;
			}
		}
		return true;
	}


	public static function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	public static function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}


class Cabecera extends SoapObject
{
	/**
	 * @var integer Propiedad de navegacin entre objetos SOAP
	 * name="CodRet" type="134"[134] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_codRet = null;
	private $_hasCodRet = false;
	public function setCodRet($value) {
		$this->_codRet = $value;
		$this->_hasCodRet = ($value !== null);
	}
	public function hasCodRet() {
		return $this->_hasCodRet;
	}
	public function getCodRet() {
		return $this->_codRet;
	}


	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="DescripcionError" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_descripcionError = null;
	private $_hasDescripcionError = false;
	public function setDescripcionError($value) {
		$this->_descripcionError = $value;
		$this->_hasDescripcionError = ($value !== null);
	}
	public function hasDescripcionError() {
		return $this->_hasDescripcionError;
	}
	public function getDescripcionError() {
		return $this->_descripcionError;
	}


	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Referencia" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_referencia = null;
	private $_hasReferencia = false;
	public function setReferencia($value) {
		$this->_referencia = $value;
		$this->_hasReferencia = ($value !== null);
	}
	public function hasReferencia() {
		return $this->_hasReferencia;
	}
	public function getReferencia() {
		return $this->_referencia;
	}


	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="FechaEmision" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_fechaEmision = null;
	private $_hasFechaEmision = false;
	public function setFechaEmision($value) {
		$this->_fechaEmision = $value;
		$this->_hasFechaEmision = ($value !== null);
	}
	public function hasFechaEmision() {
		return $this->_hasFechaEmision;
	}
	public function getFechaEmision() {
		return $this->_fechaEmision;
	}


	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Consulta" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_consulta = null;
	private $_hasConsulta = false;
	public function setConsulta($value) {
		$this->_consulta = $value;
		$this->_hasConsulta = ($value !== null);
	}
	public function hasConsulta() {
		return $this->_hasConsulta;
	}
	public function getConsulta() {
		return $this->_consulta;
	}



	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="TipoRespuesta" type="101"[101] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_tipoRespuesta = null;
	private $_hasTipoRespuesta = false;
	public function setTipoRespuesta($value) {
		$this->_tipoRespuesta = $value;
		$this->_hasTipoRespuesta = ($value !== null);
	}
	public function hasTipoRespuesta() {
		return $this->_hasTipoRespuesta;
	}
	public function getTipoRespuesta() {
		return $this->_tipoRespuesta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Cabecera con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Cabecera 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Cabecera();
		if (!isset($vData['CodRet'])) {
			throw new Exception('El parametro CodRet es obligatorio');
		}
		if (isset($vData['CodRet'])) {

			$newItem->setCodRet($vData['CodRet']);
		}
		if (!isset($vData['DescripcionError'])) {
			throw new Exception('El parametro DescripcionError es obligatorio');
		}
		if (isset($vData['DescripcionError'])) {

			$newItem->setDescripcionError($vData['DescripcionError']);
		}
		if (!isset($vData['Referencia'])) {
			throw new Exception('El parametro Referencia es obligatorio');
		}
		if (isset($vData['Referencia'])) {

			$newItem->setReferencia($vData['Referencia']);
		}
		if (!isset($vData['FechaEmision'])) {
			throw new Exception('El parametro FechaEmision es obligatorio');
		}
		if (isset($vData['FechaEmision'])) {

			$newItem->setFechaEmision($vData['FechaEmision']);
		}
		if (!isset($vData['Consulta'])) {
			throw new Exception('El parametro Consulta es obligatorio');
		}
		if (isset($vData['Consulta'])) {
			$newClass = Consulta::fromSoap($vData['Consulta']);
			$newItem->setConsulta($newClass);
		}
		if (!isset($vData['TipoRespuesta'])) {
			throw new Exception('El parametro TipoRespuesta es obligatorio');
		}
		if (isset($vData['TipoRespuesta'])) {

			$newItem->setTipoRespuesta($vData['TipoRespuesta']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_codRet, 'CodRet', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_descripcionError, 'DescripcionError', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_referencia, 'Referencia', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_fechaEmision, 'FechaEmision', 101, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_Consulta, 'Consulta', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_tipoRespuesta, 'TipoRespuesta', 101, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}

}

class DatosNacimiento extends SoapObject{

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Fecha" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Fecha = null;
	private $_hasFecha = false;
	public function setFecha($value) {
		$this->_Fecha = $value;
		$this->_hasFecha = ($value !== null);
	}
	public function hasFecha() {
		return $this->_Fecha;
	}
	public function getFecha() {
		return $this->_Fecha;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Localidad" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Localidad = null;
	private $_hasLocalidad = false;
	public function setLocalidad($value) {
		$this->_Localidad = $value;
		$this->_hasLocalidad = ($value !== null);
	}
	public function hasLocalidad() {
		return $this->_Localidad;
	}
	public function getLocalidad() {
		return $this->_Localidad;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Provincia" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Provincia = null;
	private $_hasProvincia = false;
	public function setProvincia($value) {
		$this->_Provincia = $value;
		$this->_hasProvincia = ($value !== null);
	}
	public function hasProvincia() {
		return $this->_hasProvincia;
	}
	public function getProvincia() {
		return $this->_Provincia;
	}

	/**
	 *
	 * Devuelve una instancia de la clase DatosNacimiento con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosNacimiento 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosNacimiento();
		if (isset($vData['Fecha'])) {

			$newItem->setFecha($vData['Fecha']);
		}
		if (!isset($vData['Fecha'])) {
			throw new Exception('El parametro Fecha es obligatorio');
		}
		if (isset($vData['Localidad'])) {

			$newItem->setLocalidad($vData['Localidad']);
		}
		if (!isset($vData['Localidad'])) {
			throw new Exception('El parametro Localidad es obligatorio');
		}
		if (isset($vData['Provincia'])) {

			$newItem->setProvincia($vData['Provincia']);
		}
		if (!isset($vData['Provincia'])) {
			throw new Exception('El parametro Provincia es obligatorio');
		}
		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_Fecha, 'Fecha', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_Localidad, 'Localidad', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_Provincia, 'Provincia', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class DatosTitular extends SoapObject {

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Nombre" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Nombre = null;
	private $_hasNombre = false;
	public function setNombre($value) {
		$this->_Nombre = $value;
		$this->_hasNombre = ($value !== null);
	}
	public function hasNombre() {
		return $this->_Nombre;
	}
	public function getNombre() {
		return $this->_Nombre;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Apellido1" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Apellido1 = null;
	private $_hasApellido1 = false;
	public function setApellido1($value) {
		$this->_Apellido1 = $value;
		$this->_hasApellido1 = ($value !== null);
	}
	public function hasApellido1() {
		return $this->_Apellido1;
	}
	public function getApellido1() {
		return $this->_Apellido1;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Apellido2" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Apellido2 = null;
	private $_hasApellido2 = false;
	public function setApellido2($value) {
		$this->_Apellido2 = $value;
		$this->_hasApellido2 = ($value !== null);
	}
	public function hasApellido2() {
		return $this->_Apellido2;
	}
	public function getApellido2() {
		return $this->_Apellido2;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Nacionalidad" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Nacionalidad = null;
	private $_hasNacionalidad = false;
	public function setNacionalidad($value) {
		$this->_Nacionalidad = $value;
		$this->_hasNacionalidad = ($value !== null);
	}
	public function hasNacionalidad() {
		return $this->_Nacionalidad;
	}
	public function getNacionalidad() {
		return $this->_Nacionalidad;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Sexo" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_Sexo = null;
	private $_hasSexo = false;
	public function setSexo($value) {
		$this->_Sexo = $value;
		$this->_hasSexo = ($value !== null);
	}
	public function hasSexo() {
		return $this->_Sexo;
	}
	public function getSexo() {
		return $this->_Sexo;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="DatosNacimiento" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_DatosNacimiento = null;
	private $_hasDatosNacimiento = false;
	public function setDatosNacimiento($value) {
		$this->_DatosNacimiento = $value;
		$this->_hasDatosNacimiento = ($value !== null);
	}
	public function hasDatosNacimiento() {
		return $this->_DatosNacimiento;
	}
	public function getDatosNacimiento() {
		return $this->_DatosNacimiento;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="NombrePadre" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NombrePadre = null;
	private $_hasNombrePadre = false;
	public function setNombrePadre($value) {
		$this->_NombrePadre = $value;
		$this->_hasNombrePadre = ($value !== null);
	}
	public function hasNombrePadre() {
		return $this->_NombrePadre;
	}
	public function getNombrePadre() {
		return $this->_NombrePadre;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Fecha" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NombreMadre = null;
	private $_hasNombreMadre = false;
	public function setNombreMadre($value) {
		$this->_NombreMadre = $value;
		$this->_hasNombreMadre = ($value !== null);
	}
	public function hasNombreMadre() {
		return $this->_NombreMadre;
	}
	public function getNombreMadre() {
		return $this->_NombreMadre;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="FechaCaducidad" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_FechaCaducidad = null;
	private $_hasFechaCaducidad = false;
	public function setFechaCaducidad($value) {
		$this->_FechaCaducidad = $value;
		$this->_hasFechaCaducidad = ($value !== null);
	}
	public function hasFechaCaducidad() {
		return $this->_FechaCaducidad;
	}
	public function getFechaCaducidad() {
		return $this->_FechaCaducidad;
	}

	/**
	 *
	 * Devuelve una instancia de la clase DatosTitular con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosTitular 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosTitular();

		if (isset($vData['Nombre'])) {

			$newItem->setNombre($vData['Nombre']);
		}
		if (!isset($vData['Nombre'])) {
			throw new Exception('El parametro Nombre es obligatorio');
		}
		if (isset($vData['Apellido1'])) {

			$newItem->setApellido1($vData['Apellido1']);
		}
		if (!isset($vData['Apellido1'])) {
			throw new Exception('El parametro Apellido1 es obligatorio');
		}
		if (isset($vData['Apellido2'])) {

			$newItem->setApellido2($vData['Apellido2']);
		}
		if (!isset($vData['Apellido2'])) {
			throw new Exception('El parametro Apellido2 es obligatorio');
		}
		if (isset($vData['Nacionalidad'])) {

			$newItem->setNacionalidad($vData['Nacionalidad']);
		}
		if (!isset($vData['Nacionalidad'])) {
			throw new Exception('El parametro Nacionalidad es obligatorio');
		}
		if (isset($vData['Sexo'])) {

			$newItem->setSexo($vData['Sexo']);
		}
		if (!isset($vData['Sexo'])) {
			throw new Exception('El parametro Sexo es obligatorio');
		}
		if (isset($vData['DatosNacimiento'])) {

			$newItem->setDatosNacimiento($vData['DatosNacimiento']);
		}
		if (isset($vData['NombrePadre'])) {

			$newItem->setNombrePadre($vData['NombrePadre']);
		}
		if (isset($vData['NombreMadre'])) {

			$newItem->setNombreMadre($vData['NombreMadre']);
		}
		if (isset($vData['FechaCaducidad'])) {

			$newItem->setFechaCaducidad($vData['FechaCaducidad']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_Nombre, 'Nombre', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_Apellido1, 'Apellido1', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_Apellido2, 'Apellido2', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_Nacionalidad, 'Nacionalidad', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_Sexo, 'Sexo', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_DatosNacimiento, 'DatosNacimiento', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_NombrePadre, 'NombrePadre', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_NombreMadre, 'NombreMadre', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_FechaCaducidad, 'FechaCaducidad', 101, $namespace, 0, 1, false);
		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}


class ObjetoEstado extends SoapObject
{

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="$CodigoEstado" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_CodigoEstado = null;
	private $_hasCodigoEstado = false;
	public function setCodigoEstado($value) {
		$this->_CodigoEstado = $value;
		$this->_hasCodigoEstado = ($value !== null);
	}
	public function hasCodigoEstado() {
		return $this->_CodigoEstado;
	}
	public function getCodigoEstado() {
		return $this->_CodigoEstado;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="$CodigoEstadoSecundario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_CodigoEstadoSecundario = null;
	private $_hasCodigoEstadoSecundario = false;
	public function setCodigoEstadoSecundario($value) {
		$this->_CodigoEstadoSecundario = $value;
		$this->_hasCodigoEstadoSecundario = ($value !== null);
	}
	public function hasCodigoEstadoSecundario() {
		return $this->_CodigoEstadoSecundario;
	}
	public function getCodigoEstadoSecundario() {
		return $this->_CodigoEstadoSecundario;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="$LiteralError" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_LiteralError = null;
	private $_hasLiteralError = false;
	public function setLiteralError($value) {
		$this->_LiteralError = $value;
		$this->_hasLiteralError = ($value !== null);
	}
	public function hasLiteralError() {
		return $this->_LiteralError;
	}
	public function getLiteralError() {
		return $this->_LiteralError;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="$LiteralErrorSec" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_LiteralErrorSec = null;
	private $_hasLiteralErrorSec = false;
	public function LiteralErrorSec($value) {
		$this->_LiteralErrorSec = $value;
		$this->_hasLiteralErrorSec = ($value !== null);
	}
	public function hasLiteralErrorSec() {
		return $this->_LiteralErrorSec;
	}
	public function getLiteralErrorSec() {
		return $this->_LiteralErrorSec;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="$TiempoEstimadoRespuesta" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_TiempoEstimadoRespuesta = null;
	private $_hasTiempoEstimadoRespuesta = false;
	public function setTiempoEstimadoRespuesta($value) {
		$this->_TiempoEstimadoRespuesta = $value;
		$this->_hasTiempoEstimadoRespuesta = ($value !== null);
	}
	public function hasTiempoEstimadoRespuesta() {
		return $this->_TiempoEstimadoRespuesta;
	}
	public function getTiempoEstimadoRespuesta() {
		return $this->_TiempoEstimadoRespuesta;
	}

	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Estado 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new ObjetoEstado();

		if (isset($vData['CodigoEstado'])) {

			$newItem->setCodigoEstado($vData['CodigoEstado']);
		}

		if (isset($vData['CodigoEstadoSecundario'])) {

			$newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
		}

		if (isset($vData['LiteralError'])) {

			$newItem->setLiteralError($vData['LiteralError']);
		}

		if (isset($vData['TiempoEstimadoRespuesta'])) {

			$newItem->setTiempoEstimadoRespuesta($vData['TiempoEstimadoRespuesta']);
		}
		return $newItem;

	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_CodigoEstado, 'CodigoEstado', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_CodigoEstadoSecundario, 'CodigoEstadoSecundario', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_LiteralError, 'LiteralError', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_LiteralErrorSec, 'LiteralErrorSec', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_TiempoEstimadoRespuesta, 'TiempoEstimadoRespuesta', 101, $namespace, 0, 1, false);

		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}

}

class DatosEspecificos extends SoapObject
{
	// MODE: choice

	/**
	 * @var Estado Propiedad de navegacin entre objetos SOAP
	 * name="Estado" type="135"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_Estado = null;
	private $_hasEstado = false;
	public function setEstado($value) {
		$this->_Estado = $value;
		$this->_hasEstado = ($value !== null);
	}
	public function hasEstado() {
		return $this->_hasEstado;
	}
	public function getEstado() {
		return $this->_Estado;
	}
	/**
	 * @var DatosTitular Propiedad de navegacin entre objetos SOAP
	 * name="DatosTitular" type="135"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_DatosTitular = null;
	private $_hasDatosTitular = false;
	public function setDatosTitular($value) {
		$this->_DatosTitular = $value;
		$this->_hasDatosTitular = ($value !== null);
	}
	public function hasDatosTitular() {
		return $this->_hasDatosTitular;
	}
	public function getDatosTitular() {
		return $this->_DatosTitular;
	}
	/**
	 * @var DatosNacimiento Propiedad de navegacin entre objetos SOAP
	 * name="DatosNacimiento" type="135"[135] minOccurs="1" maxOccurs="1" nillable="false"
	 */
	private $_DatosNacimiento = null;
	private $_hasDatosNacimiento = false;
	public function setDatosNacimiento($value) {
		$this->_DatosNacimiento = $value;
		$this->_hasDatosNacimiento = ($value !== null);
	}
	public function hasDatosNacimiento() {
		return $this->_hasDatosNacimiento;
	}
	public function getDatosNacimiento() {
		return $this->_DatosNacimiento;
	}



	/**
	 *
	 * Devuelve una instancia de la clase DatosEspecificos con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosEspecificos 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData)
	{
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new DatosEspecificos();
		$choiceSetted = false;

		if (isset($vData['Estado'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}
			//$choiceSetted = true;

			$newClass = ObjetoEstado::fromSoap($vData['Estado']);
			$newItem->setEstado($newClass);
		}
		if (isset($vData['DatosTitular'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = DatosTitular::fromSoap($vData['DatosTitular']);
			$newItem->setDatosTitular($newClass);
		}
		if (isset($vData['DatosTitular']['DatosNacimiento'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = DatosNacimiento::fromSoap($vData['DatosTitular']['DatosNacimiento']);
			$newItem->setDatosNacimiento($newClass);
		}


		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_Estado, 'Estado', 135, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_DatosTitular, 'DatosTitular', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_DatosNacimiento, 'DatosNacimiento', SOAP_ENC_OBJECT, $namespace, 0, 1, true);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}


}


class Consulta extends SoapObject
{

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="NumeroSoporte" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NumeroSoporte = null;
	private $_hasNumeroSoporte = false;
	public function setNumeroSoporte($value) {
		$this->_NumeroSoporte = $value;
		$this->_hasNumeroSoporte = ($value !== null);
	}

	public function hasNumeroSoporte() {
		return $this->_NumeroSoporte;
	}

	public function getNumeroSoporte() {
		return $this->_NumeroSoporte;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="AnioNacimiento" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_AnioNacimiento = null;
	private $_hasAnioNacimiento = false;
	public function setAnioNacimiento($value) {
		$this->_AnioNacimiento = $value;
		$this->_hasAnioNacimiento = ($value !== null);
	}

	public function hasAnioNacimiento() {
		return $this->_AnioNacimiento;
	}
	public function getAnioNacimiento() {
		return $this->_AnioNacimiento;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Consulta con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Consulta 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Consulta();

		if (!isset($vData['NumeroSoporte'])) {
			throw new Exception('El parametro NumeroSoporte es obligatorio');
		}
		if (isset($vData['NumeroSoporte'])) {

			$newItem->setNumeroSoporte($vData['NumeroSoporte']);
		}
		if (!isset($vData['AnioNacimiento'])) {
			throw new Exception('El parametro LocAnioNacimientoalidad es obligatorio');
		}
		if (isset($vData['AnioNacimiento'])) {

			$newItem->setAnioNacimiento($vData['AnioNacimiento']);
		}

		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_NumeroSoporte, 'NumeroSoporte', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_AnioNacimiento, 'AnioNacimiento', 134, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}


class Retorno extends SoapObject
{

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="Estado" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */

	private $_Estado = null;
	private $_hasEstado = false;
	public function setEstado($value) {
		$this->_Estado = $value;
		$this->_hasEstado = ($value !== null);
	}

	public function hasEstado() {
		return $this->_Estado;
	}

	public function getEstado() {
		return $this->_Estado;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="DatosTitular" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_DatosTitular = null;
	private $_hasDatosTitular = false;
	public function setDatosTitular($value) {
		$this->_DatosTitular = $value;
		$this->_hasDatosTitular = ($value !== null);
	}
	public function hasDatosTitular() {
		return $this->_DatosTitular;
	}
	public function getDatosTitular() {
		return $this->_DatosTitular;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Retorno con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Retorno 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Retorno();
		$choiceSetted = false;

		if (isset($vData['Estado'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = Estado::fromSoap($vData['Estado']);
			$newItem->setEstado($newClass);
		}
		if (isset($vData['DatosTitular'])) {
			if ($choiceSetted) {
				throw new Exception('No se pueden establecer multiples subetiquetas en una etiqueta de tipo CHOICE');
			}

			$newClass = DatosTitular::fromSoap($vData['DatosTitular']);
			$newItem->setDatosTitular($newClass);
		}


		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_Estado, 'Estado', SOAP_ENC_OBJECT, $namespace, 1, 1, true);
		$this->__doChild($myLevel, $this->_DatosTitular, 'DatosTitular', SOAP_ENC_OBJECT, $namespace, 0, 1, true);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}

}

class Estado extends soapObject
{
	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="CodigoEstado" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_CodigoEstado = null;
	private $_hasCodigoEstado = false;
	public function setCodigoEstado($value) {
		$this->_CodigoEstado = $value;
		$this->_hasCodigoEstado = ($value !== null);
	}
	public function hasCodigoEstado() {
		return $this->_CodigoEstado;
	}
	public function getCodigoEstado() {
		return $this->_CodigoEstado;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="CodigoEstadoSecundario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_CodigoEstadoSecundario = null;
	private $_hasCodigoEstadoSecundario = false;
	public function setCodigoEstadoSecundario($value) {
		$this->_CodigoEstadoSecundario = $value;
		$this->_hasCodigoEstadoSecundario = ($value !== null);
	}
	public function hasCodigoEstadoSecundario() {
		return $this->_CodigoEstadoSecundario;
	}
	public function getCodigoEstadoSecundario() {
		return $this->_CodigoEstadoSecundario;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="LiteralError" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_LiteralError = null;
	private $_hasLiteralError = false;
	public function setLiteralError($value) {
		$this->_LiteralError = $value;
		$this->_hasLiteralError = ($value !== null);
	}
	public function hasLiteralError() {
		return $this->_hasLiteralError;
	}
	public function getLiteralError() {
		return $this->_LiteralError;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="LiteralErrorSec" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_LiteralErrorSec = null;
	private $_hasLiteralErrorSec = false;
	public function setLiteralErrorSec($value) {
		$this->_LiteralErrorSec = $value;
		$this->_hasLiteralErrorSec = ($value !== null);
	}
	public function hasLiteralErrorSec() {
		return $this->_hasLiteralErrorSec;
	}
	public function getLiteralErrorSec() {
		return $this->_LiteralErrorSec;
	}


	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="TiempoEstimadoRespuesta" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_TiempoEstimadoRespuesta = null;
	private $_hasTiempoEstimadoRespuesta = false;
	public function setTiempoEstimadoRespuesta($value) {
		$this->_TiempoEstimadoRespuesta = $value;
		$this->_hasTiempoEstimadoRespuesta = ($value !== null);
	}
	public function hasLTiempoEstimadoRespuesta() {
		return $this->_hasTiempoEstimadoRespuestac;
	}
	public function getTiempoEstimadoRespuesta() {
		return $this->_TiempoEstimadoRespuesta;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	DatosNacimiento 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Estado();
		if (isset($vData['CodigoEstado'])) {

			$newItem->setCodigoEstado($vData['CodigoEstado']);
		}
		if (isset($vData['CodigoEstadoSecundario'])) {

			$newItem->setCodigoEstadoSecundario($vData['CodigoEstadoSecundario']);
		}

		if (isset($vData['LiteralError'])) {

			$newItem->setLiteralError($vData['LiteralError']);
		}
		if (isset($vData['LiteralErrorSec'])) {

			$newItem->setLiteralErrorSec($vData['LiteralErrorSec']);
		}
		if (isset($vData['TiempoEstimadoRespuesta'])) {

			$newItem->setTiempoEstimadoRespuesta($vData['TiempoEstimadoRespuesta']);
		}
		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_CodigoEstado, 'CodigoEstado', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_CodigoEstadoSecundario, 'CodigoEstadoSecundario', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_LiteralError, 'LiteralError', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_LiteralErrorSec, 'LiteralErrorSec', 134, $namespace, 1, 1, false);
		$this->__doChild($myLevel, $this->_TiempoEstimadoRespuesta, 'TiempoEstimadoRespuesta', 101, $namespace, 0, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}


class Procedimiento extends soapObject
{
	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="CodProcedimiento" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_CodProcedimiento = null;
	private $_hasCodProcedimiento = false;
	public function setCodProcedimiento($value) {
		$this->_CodProcedimiento = $value;
		$this->_hasCodProcedimiento = ($value !== null);
	}
	public function hasCodProcedimiento() {
		return $this->_CodProcedimiento;
	}
	public function getCodProcedimiento() {
		return $this->_CodProcedimiento;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="NombreProcedimiento" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NombreProcedimiento = null;
	private $_hasNombreProcedimiento = false;
	public function setNombreProcedimiento($value) {
		$this->_NombreProcedimiento = $value;
		$this->_hasNombreProcedimiento = ($value !== null);
	}

	public function hasNombreProcedimiento() {
		return $this->_NombreProcedimiento;
	}

	public function getNombreProcedimiento() {
		return $this->_NombreProcedimiento;
	}

	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Funcionario 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Procedimiento();
		if (!isset($vData['CodProcedimiento'])) {
			throw new Exception('El parametro CodProcedimiento es obligatorio');
		}
		if (isset($vData['CodProcedimiento'])) {

			$newItem->setCodProcedimiento($vData['CodProcedimiento']);
		}
		if (!isset($vData['NombreProcedimiento'])) {
			throw new Exception('El parametro NombreProcedimiento es obligatorio');
		}
		if (isset($vData['NombreProcedimiento'])) {

			$newItem->setNombreProcedimiento($vData['NombreProcedimiento']);
		}
		return $newItem;
	}

	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_CodProcedimiento, 'CodProcedimiento', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_NombreProcedimiento, 'NombreProcedimiento', 134, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}


class Funcionario extends soapObject
{
	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="NombreCompletoFuncionario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NombreCompletoFuncionario = null;
	private $_hasNombreCompletoFuncionario = false;
	public function setNombreCompletoFuncionario($value) {
		$this->_NombreCompletoFuncionario = $value;
		$this->_hasNombreCompletoFuncionario = ($value !== null);
	}
	public function hasNombreCompletoFuncionario() {
		return $this->_NombreCompletoFuncionario;
	}
	public function getNombreCompletoFuncionario() {
		return $this->_NombreCompletoFuncionario;
	}

	/**
	 * @var string Propiedad de navegacin entre objetos SOAP
	 * name="NifFuncionario" type="101"[101] minOccurs="0" maxOccurs="1" nillable="false"
	 */
	private $_NifFuncionario = null;
	private $_hasNifFuncionario = false;
	public function setNifFuncionario($value) {
		$this->_NifFuncionario = $value;
		$this->_hasNifFuncionario = ($value !== null);
	}
	public function hasNifFuncionario() {
		return $this->_NifFuncionario;
	}
	public function getNifFuncionario() {
		return $this->_NifFuncionario;
	}


	/**
	 *
	 * Devuelve una instancia de la clase Estado con los datos suministrados.
	 *
	 * @param string $vData Array que contiene la informacin a instanciar
	 * @return	Funcionario 	Instancia que contiene los datos suministados
	 * @access 	public
	 */
	public static function fromSoap($vData) {
		if ($vData instanceof \stdClass) $vData = (array) $vData;
		$newItem = new Funcionario();
		if (!isset($vData['NombreCompletoFuncionario'])) {
			throw new Exception('El parametro NombreCompletoFuncionario es obligatorio');
		}
		if (isset($vData['NombreCompletoFuncionario'])) {

			$newItem->setNombreCompletoFuncionario($vData['NombreCompletoFuncionario']);
		}
		if (!isset($vData['NifFuncionario'])) {
			throw new Exception('El parametro NifFuncionario es obligatorio');
		}
		if (isset($vData['NifFuncionario'])) {

			$newItem->setNifFuncionario($vData['NifFuncionario']);
		}
		return $newItem;
	}


	/**
	 *
	 * Convierte el objeto en su representacin SOAP.
	 *
	 * @param string $fieldName Nombre del campo SOAP en el que se codificar el objeto
	 * @param string $namespace Espacio de nombres del campo SOAP
	 * @return	SoapVar 	Representacin de la instancia, lista para incluir en un envo SOAP
	 * @access 	public
	 */
	public function toSoap($fieldName, $namespace) {
		$myLevel = new ArrayObject();

		$this->__doChild($myLevel, $this->_NombreCompletoFuncionario, 'NombreCompletoFuncionario', 101, $namespace, 0, 1, false);
		$this->__doChild($myLevel, $this->_NifFuncionario, 'NifFuncionario', 134, $namespace, 1, 1, false);

		//return $myLevel;
		return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}
