<?php
namespace WSCOMUN\DGT\CONDUCTORVEHICULOS;

use WSCOMUN\WSComunFClient;
use WSCOMUN\WSSSoapClient;
use ArrayObject;
use DateTime;
use Exception;
use SoapVar;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de ConductorVehiculos
 *
 * @package		WSClientConductorVehiculos
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2018 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientConductorVehiculos extends WSComunFClient
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_ESP = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';
	private static $NAMESPACE_PET = 'http://intermediacion.redsara.es/scsp/esquemas/V3/peticion';
	private static $NAMESPACE_SR  = 'http://intermediacion.redsara.es/scsp/esquemas/V3/solicitudRespuesta';


	/**
	 * Devuelve la instancia del cliente WSSSoapClient ya configurado, o null si no existe.
	 *
	 * @access	private
	 * @return	WSSSoapClient	Devuelve el objeto o null si error
	 */
	private function crearCliente() {
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		$this->__clienteOn(self::KEYCLIENTE_DGT_CONDUCTORVEHICULOS, true, $opcionesClienteWS);
		$clienteWS = $this->__getClient(self::KEYCLIENTE_DGT_CONDUCTORVEHICULOS);

		return $clienteWS;
	}


	/**
	 * Realiza una peticin sncrona al servidor con una nica solicitud.
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	objSolicitudTransmision	$oSolicitud	Solicitud a enviar
	 * @return	???	Respuesta del servidor
	 */
	public function peticionSincrona($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();

			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_petSinc($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'Peticion', self::$NAMESPACE_PET);
			$respuesta = $clienteWS->peticionSincrona($miSoapRQ);

			// TODO: CONVERTIR RESPUESTA EN OBJETO!!!

			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//peticionSincrona


	/**
	 * Realiza una peticin asncrona al servidor con una o varias solicitudes
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	array<objSolicitudTransmision>	$vSolicitudes	Array con las solicitudes a enviar
	 * @return	???	Respuesta del servidor
	 */
	public function peticionAsincrona($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();

			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_petAsinc($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null, 'Peticion', self::$NAMESPACE_PET);
			$respuesta = $clienteWS->peticionAsincrona($miSoapRQ);

			// TODO: CONVERTIR RESPUESTA EN OBJETO!!!

			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//peticionAsincrona


	/**
	 * Realiza una solicitud de respuesta a una peticin asncrona previa
	 *
	 * @access	public
	 * @param	string	$IdPeticion	Identificador de la peticin original
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje de la peticin original
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @return	???	Respuesta del servidor
	 */
	public function solicitudRespuesta($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		try
		{
			// Crea el cliente del WS
			$clienteWS = $this->crearCliente();

			// Genera el SoapVar a enviar
			$bodyWSRequest = $this->toSOAP_SR($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos);

			// Envio peticion
			$miSoapRQ = new SoapVar($bodyWSRequest, SOAP_ENC_OBJECT,null,null,'SolicitudRespuesta', self::$NAMESPACE_SR);
			$respuesta = $clienteWS->solicitudRespuesta($miSoapRQ);

			// TODO: CONVERTIR RESPUESTA EN OBJETO!!!

			// Respuesta
			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//solicitudRespuesta


	/**
	 * Compone el SoapVar correspondiente a la etiqueta Atributos
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	string	$ns	Namespace especifico a utilizar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_atributos($idPeticion, $numElementos, $timestamp, $codigoCertificado, $ns) {
		// Atributos
		$AtrWSLvl = new ArrayObject();
		$AtrWSLvl->append(new SoapVar($idPeticion, XSD_STRING, null, null,'IdPeticion', $ns));
		$AtrWSLvl->append(new SoapVar($numElementos, XSD_INTEGER , null, null,'NumElementos', $ns));
		$AtrWSLvl->append(new SoapVar($timestamp->format(DateTime::ATOM), XSD_STRING, null, null,'TimeStamp', $ns));
		$AtrWSLvl->append(new SoapVar($codigoCertificado, XSD_STRING, null, null,'CodigoCertificado', $ns));

		return new SoapVar($AtrWSLvl, SOAP_ENC_OBJECT, null, null, 'Atributos', $ns);
	}

	/**
	 * Compone el SoapVar correspondiente a las peticiones sincronas
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	objSolicitudTransmision	$oSolicitud	Solicitud a enviar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_petSinc($IdPeticion, $TimeStamp, $CodigoCertificado, $oSolicitud)
	{
		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, 1, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_PET);

		// SolicitudTransmision
		$SolicitudTransmisionSoapVar = $oSolicitud->toSoap($IdPeticion, $CodigoCertificado, null);

		// Solicitudes
		$SolicitudesWSRequest = new ArrayObject();
		$SolicitudesWSRequest->append($SolicitudTransmisionSoapVar);

		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);
		$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT, null, null, 'Solicitudes', self::$NAMESPACE_PET));

		return $bodyWSRequest;
	} //toSOAP_petSinc


	/**
	 * Compone el SoapVar correspondiente a las peticiones asincronas
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	array<objSolicitudTransmision>	$vSolicitudes	Array con las solicitudes a enviar
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_petAsinc($IdPeticion, $TimeStamp, $CodigoCertificado, $vSolicitudes)
	{
		// Cuenta el numero de solicitudes
		$NumElementos = count($vSolicitudes);

		// Solicitudes
		$SolicitudesWSRequest = new ArrayObject();

		for ($iPet=0; $iPet < $NumElementos; $iPet++) {
			$oSolicitud = $vSolicitudes[$iPet];

			// SolicitudTransmision
			$SolicitudTransmisionSoapVar = $oSolicitud->toSoap($IdPeticion, $CodigoCertificado, $iPet);

			// Aade la solicitud de transmision al listado de solicitudes
			$SolicitudesWSRequest->append($SolicitudTransmisionSoapVar);
		}

		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, $NumElementos, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_PET);

		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);
		$bodyWSRequest->append(new SoapVar($SolicitudesWSRequest, SOAP_ENC_OBJECT,null,null,'Solicitudes', self::$NAMESPACE_PET));

		return $bodyWSRequest;
	} //toSOAP_petAsinc

	/**
	 * Compone el SoapVar correspondiente a las solicitudes de respuesta
	 *
	 * @access	private
	 * @param	string	$IdPeticion	Identificador de la peticin
	 * @param	DateTime	$TimeStamp	Fecha y hora del envo del mensaje
	 * @param	string	$CodigoCertificado	Cdigo del certificado del servicio que solicita la peticion
	 * @param	integer	$NumElementos	Nmero de elementos de la peticion original
	 * @return	SoapVar 	Representacin de la etiqueta, lista para incluir en un envo SOAP
	 */
	private function toSOAP_SR($IdPeticion, $TimeStamp, $CodigoCertificado, $NumElementos)
	{
		// Atributos
		$AtrSoapVar = $this->toSOAP_atributos($IdPeticion, $NumElementos, $TimeStamp, $CodigoCertificado, self::$NAMESPACE_SR);

		// Body
		$bodyWSRequest = new ArrayObject();
		$bodyWSRequest->append($AtrSoapVar);

		return $bodyWSRequest;
	} //toSOAP_SR

}

?>