<?php
namespace WSCOMUN\TRANSFORMAPDF;
use WSCOMUN\WSComunFClient;
use Exception;


include_once 'class/transformImage.php';
include_once 'class/transformDocument.php';



/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Transformacin de documentos a PDF
 *
 * @package		WSClientTransformaPDF
 * @author 		Pablo Castellano <castellano_pab@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2020 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientTransformaPDF extends WSComunFClient
{



	/**
	 *Transforma un documento a PDF
	 *Formatos soportados : doc, docx, odt, rtf.
	 *El servicio acepta documentos de maximo 60MB
	 * @param String Documento en Base64
	 * @param String MimeType del formato del documento original
	 * @return String Documento PDF en Base64
	 *
	 */
	public function transformDocument ($documento,$formato)
	{
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		$clienteWS = null;
		try
		{
			//Creacion cliente SOAP
			$this->__clienteOn(self::KEYCLIENTE_TRANSFORMA_PDF, true, $opcionesClienteWS);
			/** @var \WSCOMUN\WSComunFClient $clienteWS */
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_TRANSFORMA_PDF];

			//Argumentos de la peticion
			$peticion = new transformDocument($documento, $formato, 'pdf');

			//Peticion
			$pdf = $clienteWS->__soapCall('transformDocument',array($peticion));

			//Por defecto devuelve la cadena en binario
			//Se vuelve a codificar para evitar errores al transferirla
			$encode = base64_encode($pdf->return);
			return ($encode);

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//transformDocument


	/**
	 * Transforma una imagen a PDF
	 * Formatos soportados: Xml, gif, jpg, odt, doc, tif, bmp, docx, rtf.
	 * El servicio acepta documentos de maximo 60MB
	 * @param String Documento en Base64
	 * @param String MimeType del formato del documento original
	 * @return String Documento PDF en Base64
	 *
	 */
	public function transformImage ($imagen,$formato)
	{
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_TRANSFORMA_PDF, true, $opcionesClienteWS);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_TRANSFORMA_PDF];
			$peticion = new transformImage($imagen, $formato, 'pdf');

			$pdf = $clienteWS->__soapCall('transformImage', array($peticion));

			$encode = base64_encode($pdf->return);

			return $encode;

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}

}

?>